==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/broom/dialogs_cs.lua <==

dialogId("kos-m-uklid0", "font_small", "It`s been a long time since we`ve been here...")
dialogStr("Tady jsme už dlouho nebyli.")


dialogId("kos-m-uklid1", "font_small", "Nobody has cleaned up in here for a long time.")
dialogStr("Tady se už dlouho neuklízelo.")


dialogId("kos-m-uklid2", "font_small", "I knew we`d have to clean this room up.")
dialogStr("Já jsem věděla, že tu budeme muset uklízet.")


dialogId("kos-v-poradek0", "font_big", "At least we can tidy things up.")
dialogStr("Aspoň tu uděláme pořádek.")


dialogId("kos-v-poradek1", "font_big", "At least things will finally be in order in here.")
dialogStr("Konečně tu bude pořádek.")


dialogId("kos-v-poradek2", "font_big", "I`ll have to do the sweeping.")
dialogStr("Tady budu muset zametat já.")


dialogId("kos-v-koste0", "font_big", "It`s a good thing we have that broom.")
dialogStr("Ještě že tu máme to koště.")


dialogId("kos-v-koste1", "font_big", "Could you please hand me that broom?")
dialogStr("Podáš mi, prosím tě, to koště?")


dialogId("kos-v-koste2", "font_big", "Could you please hand me that broom? And try not to drop it on my head.")
dialogStr("Podáš mi, prosím tě, to koště? A zkus mi ho nehodit na hlavu.")


dialogId("kos-m-zamet0", "font_small", "I think it`ll be fine if you just sweep it all down there.")
dialogStr("Myslím, že bude stačit, když to všechno zameteš dolů.")


dialogId("kos-m-zamet1", "font_small", "It should all fit.")
dialogStr("Tam se toho vejde.")


dialogId("kos-m-zamet2", "font_small", "Just sweep it down and we`ll be out of here.")
dialogStr("Jenom to zameť dolů a padáme.")


dialogId("kos-m-zamet3", "font_small", "Forget that bin and just sweep the garbage down.")
dialogStr("Na uhlák se vykašli a nameť to dolů.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/broom/dialogs_cs.lua <==

dialogId("kos-m-uklid0", "font_small", "It’s been a long time since we’ve been here...")
dialogStr("Tady jsme už dlouho nebyli.")


dialogId("kos-m-uklid1", "font_small", "Nobody has cleaned up in here for a long time.")
dialogStr("Tady se už dlouho neuklízelo.")


dialogId("kos-m-uklid2", "font_small", "I knew we’d have to clean this room up.")
dialogStr("Já jsem věděla, že tu budeme muset uklízet.")


dialogId("kos-v-poradek0", "font_big", "At least we can tidy things up.")
dialogStr("Aspoň tu uděláme pořádek.")


dialogId("kos-v-poradek1", "font_big", "At least things will finally be in order in here.")
dialogStr("Konečně tu bude pořádek.")


dialogId("kos-v-poradek2", "font_big", "I’ll have to do the sweeping.")
dialogStr("Tady budu muset zametat já.")


dialogId("kos-v-koste0", "font_big", "It’s a good thing we have that broom.")
dialogStr("Ještě že tu máme to koště.")


dialogId("kos-v-koste1", "font_big", "Could you please hand me that broom?")
dialogStr("Podáš mi, prosím tě, to koště?")


dialogId("kos-v-koste2", "font_big", "Could you please hand me that broom? And try not to drop it on my head.")
dialogStr("Podáš mi, prosím tě, to koště? A zkus mi ho nehodit na hlavu.")


dialogId("kos-m-zamet0", "font_small", "I think it’ll be fine if you just sweep it all down there.")
dialogStr("Myslím, že bude stačit, když to všechno zameteš dolů.")


dialogId("kos-m-zamet1", "font_small", "It should all fit.")
dialogStr("Tam se toho vejde.")


dialogId("kos-m-zamet2", "font_small", "Just sweep it down and we’ll be out of here.")
dialogStr("Jenom to zameť dolů a padáme.")


dialogId("kos-m-zamet3", "font_small", "Forget that bin and just sweep the garbage down.")
dialogStr("Na uhlák se vykašli a nameť to dolů.")
